@@ -13,7 +13,7 @@ use Config;
 
 # ABSTRACT: Translate an IDL source to an AST
 
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 
 use Carp qw/carp croak/;
@@ -119,12 +119,14 @@ sub generate {
 	croak '3rd argument must be a pointer to HASH';
     }
 
-    my $moduleDir = module_dir(__PACKAGE__);
+    my $packageDist = __PACKAGE__;
+    $packageDist =~ s/::/-/g;
+    my $distDir = dist_dir($packageDist);
     my $ttOptionHashp = $targetOptionHashp->{tt};
     $ttOptionHashp->{STRICT} //= 1;
     $ttOptionHashp->{DELIMITER} //= $Config{path_sep};
     $ttOptionHashp->{INCLUDE_PATH} //= '';
-    $ttOptionHashp->{INCLUDE_PATH} .= $ttOptionHashp->{DELIMITER} . $moduleDir;
+    $ttOptionHashp->{INCLUDE_PATH} .= $ttOptionHashp->{DELIMITER} . $distDir;
     $ttOptionHashp->{INTERPOLATE} //= 1;
     $ttOptionHashp->{EVAL_PERL} //= 1;
     $ttOptionHashp->{PRE_CHOMP} //= CHOMP_NONE;
@@ -165,7 +167,7 @@ MarpaX::Languages::IDL::AST - Translate an IDL source to an AST
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
